# memorandum
Command line tool to display calendar in terminal, mutt, etc.

# Auto-configuration
Run memorandum ("./memorandum.py" if cloned from git or "python3 -m memorandum"
if installed from pypi) and answer configuration questions.

It will install :
  * a configuration file in "~/.config/memorandum/memorandum.rc"
  * and if you wish an "memorandum" alias in "~/.bash_aliases".

# Command line usage

## Run
The first run is made via:
  * "python3 -m memorandum" if module is installed from pypi,
  * "./memorandum.py" if cloned from git.
Then if you have installed the pypi module and created the alias, run it with :
"memorandum"

## Options
The main options are:
  * "memorandum": display today events
  * "memorandum -w": display this week events
  * "memorandum -m": display this month events
  * "memorandum -d YYYYMMDD": display the corresponding day events
  * "memorandum -w -d YYYYMMDD": display the corresponding week events
  * "memorandum -m -d YYYYMMDD": display the corresponding month events
  * "memorandum -c": create e new event

# TODO: Mutt usage

## TODO: Add to .mailcap file:
text/calendar; path/memorandum/cal.py '%s'; nametemplate=%s.ics; copiousoutput;

## TODO: Add to .muttrc file:
auto_view text/calendar
